"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const information_1 = require("./src/steps/information");
const github_1 = require("./src/steps/github");
const changelog_1 = require("./src/steps/changelog");
const log_1 = require("./src/log");
const git_1 = require("./src/steps/git");
const package_json_1 = require("./src/steps/package-json");
async function automaticRelease() {
    return new Promise(async (resolve, reject) => {
        log_1.log();
        log_1.log('title', 'AUTOMATIC RELEASE');
        log_1.log();
        const startTime = new Date().getTime();
        try {
            log_1.log('step', 'Collect information');
            const info = await information_1.collectInformation();
            log_1.log();
            log_1.log('step', 'Update "package.json" file');
            await package_json_1.updatePackageJson(info.newVersion);
            log_1.log();
            log_1.log('step', 'Generate "CHANGELOG.md" file');
            await changelog_1.generateAndWriteChangelog(info.repositoryUrl);
            log_1.log();
            log_1.log('step', 'Save changes to Git');
            await git_1.saveChangesToGit(info.newVersion);
            log_1.log();
            log_1.log('step', 'Create GitHub release');
            await github_1.createAllGithubReleases(info.repositoryOwner, info.repositoryName, info.repositoryUrl, info.githubToken);
            const finishTime = new Date().getTime();
            const processTime = ((finishTime - startTime) / 1000).toFixed(2);
            log_1.log();
            if (info.isFirstVersion) {
                log_1.log('success', `Release of version ${info.newVersion} successful (first release)! [${processTime} seconds]`);
            }
            else {
                log_1.log('success', `Release of version ${info.newVersion} successful (previously ${info.oldVersion})! [${processTime} seconds]`);
            }
            log_1.log();
            resolve();
        }
        catch (error) {
            log_1.log();
            log_1.log('error', error.message);
            log_1.log();
            reject(error);
        }
    });
}
exports.automaticRelease = automaticRelease;
//# sourceMappingURL=index.js.map