"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const path = require("path");
const conventionalChangelog = require("conventional-changelog");
const changelog_transform_1 = require("./../templates/changelog-transform");
const log_1 = require("./../log");
const read_file_1 = require("./../utilities/read-file");
const write_file_1 = require("./../utilities/write-file");
async function generateAndWriteChangelog(repositoryUrl) {
    log_1.log('substep', 'Generage changelog');
    const changelogTemplates = await readChangelogTemplateFiles();
    const changelog = await generateChangelog(changelogTemplates, repositoryUrl);
    log_1.log('substep', 'Write the "CHANGELOG.md" file');
    await write_file_1.writeFile('CHANGELOG.md', changelog);
}
exports.generateAndWriteChangelog = generateAndWriteChangelog;
function generateChangelog(changelogTemplates, repositoryUrl) {
    return new Promise(async (resolve, reject) => {
        const changelogChunks = [];
        changelogChunks.push('# Changelog\n\n');
        changelogChunks.push(`Also see the **[release page](${repositoryUrl}/releases)**.\n`);
        const changelogStream = conventionalChangelog({
            pkg: {
                path: path.resolve(process.cwd(), 'package.json')
            },
            preset: 'angular',
            releaseCount: 0
        }, {
            linkCompare: false
        }, {}, {}, {
            transform: changelog_transform_1.changelogTransformer(repositoryUrl),
            mainTemplate: changelogTemplates.mainTemplate,
            commitPartial: changelogTemplates.commitTemplate,
            headerPartial: changelogTemplates.headerTemplate,
            footerPartial: changelogTemplates.footerTemplate
        });
        changelogStream.on('error', (error) => {
            reject(new Error(`An error occured while generating the changelog. [${error.message}]`));
            return;
        });
        changelogStream.on('data', (dataChunk) => {
            changelogChunks.push(dataChunk);
        });
        changelogStream.on('end', () => {
            changelogChunks.push('\n<br>\n\n---\n\n<sup>*Changelog generated automatically by [automatic-release](https://github.com/dominique-mueller/automatic-release).*</sup>\n');
            const changelog = changelogChunks.join('');
            resolve(changelog);
        });
    });
}
async function readChangelogTemplateFiles() {
    const [mainTemplate, commitTemplate, headerTemplate, footerTemplate] = await Promise.all([
        read_file_1.readFile('./../templates/changelog-main.hbs', true),
        read_file_1.readFile('./../templates/changelog-commit.hbs', true),
        read_file_1.readFile('./../templates/changelog-header.hbs', true),
        read_file_1.readFile('./../templates/changelog-footer.hbs', true)
    ]);
    const templates = {
        mainTemplate,
        commitTemplate,
        headerTemplate,
        footerTemplate
    };
    return templates;
}
exports.readChangelogTemplateFiles = readChangelogTemplateFiles;
//# sourceMappingURL=changelog.js.map