"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const git = require("simple-git");
const log_1 = require("./../log");
const resolve_path_1 = require("./../utilities/resolve-path");
function saveChangesToGit(newVersion) {
    return new Promise((resolve, reject) => {
        try {
            git(process.cwd())
                .exec(() => {
                log_1.log('substep', 'Commit all changes (CI will be skipped)');
            })
                .add(resolve_path_1.resolvePath('package.json'))
                .add(resolve_path_1.resolvePath('CHANGELOG.md'))
                .commit(`Release ${newVersion} [skip ci]`)
                .exec(() => {
                log_1.log('substep', 'Create a Git version tag');
            })
                .addAnnotatedTag(newVersion, `Release of version ${newVersion}.`)
                .exec(() => {
                log_1.log('substep', 'Push both commit & tag to remote');
            })
                .push('origin', 'master', {
                '--follow-tags': null
            })
                .exec(() => {
                log_1.log('substep', 'Update develop branch with the latest master');
            })
                .checkout('develop')
                .merge(['master'])
                .push('origin', 'develop')
                .checkout('master')
                .exec(() => {
                resolve();
            });
        }
        catch (error) {
            reject(new Error(`An error occured while saving the changes to Git. [${error.message}]`));
            return;
        }
    });
}
exports.saveChangesToGit = saveChangesToGit;
//# sourceMappingURL=git.js.map