"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const path = require("path");
const githubReleaser = require("conventional-github-releaser");
const githubRemoveAllReleases = require("github-remove-all-releases");
const changelog_transform_1 = require("./../templates/changelog-transform");
const log_1 = require("./../log");
const changelog_1 = require("./changelog");
async function createAllGithubReleases(repositoryOwner, repositoyName, repositoryUrl, githubToken) {
    log_1.log('substep', 'Delete all existing GitHub releases');
    await deleteAllGithubReleases(repositoryOwner, repositoyName, githubToken);
    log_1.log('substep', 'Create all GitHub releases');
    const changelogTemplates = await changelog_1.readChangelogTemplateFiles();
    await createGithubReleases(changelogTemplates, repositoryUrl, githubToken);
}
exports.createAllGithubReleases = createAllGithubReleases;
function createGithubReleases(changelogTemplates, repositoryUrl, githubToken) {
    return new Promise(async (resolve, reject) => {
        githubReleaser({
            type: 'oauth',
            token: githubToken
        }, {
            pkg: {
                path: path.resolve(process.cwd(), 'package.json')
            },
            preset: 'angular',
            releaseCount: 0
        }, {
            linkCompare: false
        }, {}, {}, {
            transform: changelog_transform_1.changelogTransformer(repositoryUrl),
            mainTemplate: changelogTemplates.mainTemplate,
            commitPartial: changelogTemplates.commitTemplate,
            headerPartial: '',
            footerPartial: changelogTemplates.footerTemplate
        }, (error, response) => {
            if (error) {
                reject(new Error(`An error occured while creating GitHub releases. [${error.message}]`));
                return;
            }
            resolve();
        });
    });
}
function deleteAllGithubReleases(owner, name, githubToken) {
    return new Promise((resolve, reject) => {
        githubRemoveAllReleases({
            type: 'oauth',
            token: githubToken
        }, owner, name, (error, response) => {
            if (error && error.toString() !== 'Error: No releases found') {
                reject(new Error(`An error occured while deleting GitHub releases. [${error.message}]`));
                return;
            }
            resolve();
        });
    });
}
//# sourceMappingURL=github.js.map