"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
function changelogTransformer(repositoryUrl) {
    return (commit) => {
        commit.notes.forEach((note) => {
            note.title = 'BREAKING CHANGES';
        });
        switch (commit.type) {
            case 'feat':
                commit.type = 'Features';
                break;
            case 'fix':
                commit.type = 'Bug Fixes';
                break;
            case 'perf':
                commit.type = 'Performance Improvements';
                break;
            case 'style':
                commit.type = 'Styles';
                break;
            case 'docs':
                commit.type = 'Documentation';
                break;
            case 'refactor':
                commit.type = 'Refactoring';
                break;
            case 'test':
                commit.type = 'Tests';
                break;
            case 'chore':
                commit.type = 'Chores';
                break;
            case 'revert':
                commit.type = 'Reverts';
                break;
            default:
                return;
        }
        if (commit.scope === '*') {
            commit.scope = '';
        }
        if (typeof commit.hash === 'string') {
            commit.hash = commit.hash.substring(0, 7);
        }
        const issues = [];
        if (typeof commit.subject === 'string') {
            commit.subject = commit.subject
                .replace(/#([0-9]+)/g, function (match, issue) {
                issues.push(issue);
                return `[#${issue}](${repositoryUrl}/issues/${issue})`;
            })
                .replace(/@([a-zA-Z0-9_]+)/g, '[@$1](https://github.com/$1)');
        }
        commit.references = commit.references.filter((reference) => {
            return issues.indexOf(reference.issue) === -1;
        });
        return commit;
    };
}
exports.changelogTransformer = changelogTransformer;
;
//# sourceMappingURL=changelog-transform.js.map