"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const fs = require("fs");
const path = require("path");
const resolve_path_1 = require("./resolve-path");
function readFile(filePath, isWithinLibrary = false) {
    return new Promise((resolve, reject) => {
        const resolvedFilePath = resolve_path_1.resolvePath(filePath, isWithinLibrary);
        fs.readFile(resolvedFilePath, 'utf-8', (readFileError, fileContent) => {
            if (readFileError) {
                reject(new Error(`An error occured while reading the file "${resolvedFilePath}". [Code "${readFileError.code}", Number "${readFileError.errno}"]`));
                return;
            }
            let parsedFileContent = fileContent;
            if (path.extname(resolvedFilePath).replace('.', '').toLowerCase() === 'json') {
                try {
                    parsedFileContent = JSON.parse(fileContent);
                }
                catch (jsonParseError) {
                    reject(new Error(`An error occured while parsing the file "${resolvedFilePath}" as JSON. [${jsonParseError.message}]`));
                    return;
                }
            }
            resolve(parsedFileContent);
        });
    });
}
exports.readFile = readFile;
//# sourceMappingURL=read-file.js.map